Rename OpenGGSN to OsmoGGSN

Osmocom has maintained this program since about 7 years now, while
the original author / copyright holder has completely disappeared.

With the introduction of Osmocom-style CTRL and VTY interfaces,
the way how the program is used and configured has substantially
changed.  In order to avoid confusion in terms of configuration file
format etc, let's rename it to OsmoGGSN.

Change-Id: I2da30f7d4828e185bfac1a4e2d8414b01cbe4f9d
diff --git a/ggsn/ggsn.c b/ggsn/ggsn.c
index ee64cb9..0b877cf 100644
--- a/ggsn/ggsn.c
+++ b/ggsn/ggsn.c
@@ -1,5 +1,5 @@
 /* 
  * OpenGGSN - Gateway GPRS Support Node
  * Copyright (C) 2002, 2003, 2004 Mondru AB.
  * Copyright (C) 2017 by Harald Welte <laforge@gnumonks.org>
  * 
@@ -592,7 +592,7 @@
 	return tun_encaps((struct tun_t *)pdp->ipif, pack, len);
 }
 
-static char *config_file = "openggsn.cfg";
+static char *config_file = "osmo-ggsn.cfg";
 
 /* callback for tun device osmocom select loop integration */
 static int ggsn_tun_fd_cb(struct osmo_fd *fd, unsigned int what)
@@ -804,7 +804,7 @@
 	struct ggsn_ctx *ggsn;
 	int rc;
 
-	tall_ggsn_ctx = talloc_named_const(NULL, 0, "openggsn");
+	tall_ggsn_ctx = talloc_named_const(NULL, 0, "OsmoGGSN");
 	msgb_talloc_ctx_init(tall_ggsn_ctx, 0);
 
 	/* Handle keyboard interrupt SIGINT */
@@ -1,5 +1,5 @@
 /* 
- * OpenGGSN - Gateway GPRS Support Node
+ * OsmoGGSN - Gateway GPRS Support Node
  * Copyright (C) 2002, 2003, 2004 Mondru AB.
  * Copyright (C) 2017 by Harald Welte <laforge@gnumonks.org>